PyDM - Python Display Manager
=============================

PyDM is a Python-Qt based framework for building user interfaces for control systems.

The goal is to provide a no-code, drag-and-drop system to make simple screens,
as well as a straightforward python framework to build complex applications.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   installation.rst

.. toctree::
   :maxdepth: 1
   :caption: Configuration

   configuration.rst


.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   tutorials/index.rst

.. toctree::
   :maxdepth: 2
   :caption: User & API Documentation

   stylesheets.rst
   help_files.rst
   widgets/index.rst
   widgets/widget_rules/index.rst
   add_data_plugins.rst
   application.rst
   channel.rst
   utilities/index.rst

.. toctree::
   :maxdepth: 1
   :caption: Data Plugins

   data_plugins/local_plugin.rst
   data_plugins/calc_plugin.rst
   data_plugins/p4p_plugin.rst
   data_plugins/external_plugins.rst

.. toctree::
   :maxdepth: 1
   :caption: Developers Corner

   development/development.rst
   development/external_tools.rst
   widgets/widget_rules/customizing.rst
   development/designer_widgets.rst
   development/resources.rst

.. toctree::
   :maxdepth: 1
   :caption: Links
   :hidden:

   PyDM GitHub <https://github.com/slaclab/pydm>
   SLAC-wide GitHub <https://github.com/slaclab>
